@@ -106,7 +106,8 @@ class TxtRegPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -157,7 +158,8 @@ class TxtRegPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -179,7 +181,8 @@ class TxtRegPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -195,7 +198,7 @@ class TxtRegPostProcessor(IPostProcessor):
         if self.config.start_save_epoch == -1 or self.config.start_save_step == -1:
             self.config.start_save_step = rt_config.get('total_steps', 0) - 1
             self.config.start_save_epoch = rt_config.get('total_epochs', 0) - 1
-        if rt_config['current_step']>=self.config.start_save_step or rt_config['current_epoch']>=self.config.start_save_epoch:
+        if not save_condition and (rt_config['current_step']>=self.config.start_save_step or rt_config['current_epoch']>=self.config.start_save_epoch):
             save_condition = True
         if save_condition:
             save_path = os.path.join(self.config.save_root_path, self.config.save_path.get(stage, ''))
@@ -206,4 +209,5 @@ class TxtRegPostProcessor(IPostProcessor):
             else:
                 save_file = os.path.join(save_path, 'predict.json')
             logger.info(f"Save the {stage} predict data at {save_file}")
-            json.dump(predicts, open(save_file, 'w'), indent=4)
+            json.dump(predicts, open(save_file, 'w'), indent=4, ensure_ascii=False)
+
